import { _Filter } from "./_Filter";
import { NodeHttpOptions as __HttpOptions__ } from "@aws-sdk/types";
import * as __aws_sdk_types from "@aws-sdk/types";
/**
 * DescribeDBEngineVersionsInput shape
 */
export interface DescribeDBEngineVersionsInput {
    /**
     * <p>The database engine to return.</p>
     */
    Engine?: string;
    /**
     * <p>The database engine version to return.</p> <p>Example: <code>5.1.49</code> </p>
     */
    EngineVersion?: string;
    /**
     * <p>The name of a specific DB parameter group family to return details for.</p> <p>Constraints:</p> <ul> <li> <p>If supplied, must match an existing DBParameterGroupFamily.</p> </li> </ul>
     */
    DBParameterGroupFamily?: string;
    /**
     * <p>This parameter is not currently supported.</p>
     */
    Filters?: Array<_Filter> | Iterable<_Filter>;
    /**
     * <p> The maximum number of records to include in the response. If more than the <code>MaxRecords</code> value is available, a pagination token called a marker is included in the response so that the following results can be retrieved. </p> <p>Default: 100</p> <p>Constraints: Minimum 20, maximum 100.</p>
     */
    MaxRecords?: number;
    /**
     * <p> An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by <code>MaxRecords</code>. </p>
     */
    Marker?: string;
    /**
     * <p>A value that indicates whether only the default version of the specified engine or engine and major version combination is returned.</p>
     */
    DefaultOnly?: boolean;
    /**
     * <p>A value that indicates whether to list the supported character sets for each engine version.</p> <p>If this parameter is enabled and the requested engine supports the <code>CharacterSetName</code> parameter for <code>CreateDBInstance</code>, the response includes a list of supported character sets for each engine version. </p>
     */
    ListSupportedCharacterSets?: boolean;
    /**
     * <p>A value that indicates whether to list the supported time zones for each engine version.</p> <p>If this parameter is enabled and the requested engine supports the <code>TimeZone</code> parameter for <code>CreateDBInstance</code>, the response includes a list of supported time zones for each engine version. </p>
     */
    ListSupportedTimezones?: boolean;
    /**
     * <p>A value that indicates whether to include engine versions that aren't available in the list. The default is to list only available engine versions.</p>
     */
    IncludeAll?: boolean;
    /**
     * The maximum number of times this operation should be retried. If set, this value will override the `maxRetries` configuration set on the client for this command.
     */
    $maxRetries?: number;
    /**
     * An object that may be queried to determine if the underlying operation has been aborted.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal
     */
    $abortSignal?: __aws_sdk_types.AbortSignal;
    /**
     * Per-request HTTP configuration options. If set, any options specified will override the corresponding HTTP option set on the client for this command.
     */
    $httpOptions?: __HttpOptions__;
}
