/**
 * <p>Option settings are the actual settings being applied or configured for that option. It is used when you modify an option group or describe option groups. For example, the NATIVE_NETWORK_ENCRYPTION option has a setting called SQLNET.ENCRYPTION_SERVER that can have several different values.</p>
 */
export interface _OptionSetting {
    /**
     * <p>The name of the option that has settings that you can set.</p>
     */
    Name?: string;
    /**
     * <p>The current value of the option setting.</p>
     */
    Value?: string;
    /**
     * <p>The default value of the option setting.</p>
     */
    DefaultValue?: string;
    /**
     * <p>The description of the option setting.</p>
     */
    Description?: string;
    /**
     * <p>The DB engine specific parameter type.</p>
     */
    ApplyType?: string;
    /**
     * <p>The data type of the option setting.</p>
     */
    DataType?: string;
    /**
     * <p>The allowed values of the option setting.</p>
     */
    AllowedValues?: string;
    /**
     * <p>A Boolean value that, when true, indicates the option setting can be modified from the default.</p>
     */
    IsModifiable?: boolean;
    /**
     * <p>Indicates if the option setting is part of a collection.</p>
     */
    IsCollection?: boolean;
}
export declare type _UnmarshalledOptionSetting = _OptionSetting;
